/****************************************************************************
Date: 4/26/98
File: itune.hpp

Description:
	InstantTune command line control program definitions
	Controls TSR through command interrupt
History:
	 9/11/95
	  4/26 added code for MODE command
*****************************************************************************/
#ifndef ITUNE_HPP
#define ITUNE_HPP

#include <stddef.h>
#include <stdarg.h>
#include <stdlib.h>
#include <dos.h>
#include <process.h>
#include <stdio.h>

#include "loctypes.h"
#include "dospc.h"	// non-ANSI dos functions
#include "mycout.hpp"	// local "cout" 

#include "istsr.hpp"	// is TSR loaded? utility
#include "cmd.hpp"	// Command Interpreter definitions
#include "cfg.hpp"	// configuration server class


//***** ITUNE command line options ***********************************
const CHAR* ITUNE_OPTIONS =
"InstantTune command line options:\n\
c(eck)................................Check TSR status\n\
d(ebug)...............................Display debug info\n\
h(alt)................................Stop tuning\n\
l(oad)................................Load the TSR\n\
m(ode) SATELLITE TRANSPONDERMODE......Select mode for this satellite\n\
s(elect) SATELLITE....................Select Satellite\n\
t(une) VELOCITY.......................Tune radios for specified velocity\n\
v(erify)..............................Verify the configuration file\n\
";

//***** Itune Commands ***************************************************
const CHAR ITUNE_CHECK		= 'c';
const CHAR ITUNE_DEBUG		= 'd';
const CHAR ITUNE_HALT		= 'h';
const CHAR ITUNE_LOAD		= 'l';
const CHAR ITUNE_SETMODE	= 'm';
const CHAR ITUNE_SETSATELLITE	= 's';
const CHAR ITUNE_TUNE		= 't';
const CHAR ITUNE_VERIFY		= 'v';

//***** InstantTune TSR name *******************************************
const CHAR* ITUNE_TSRNAME	= "itunetsr";

//***** Configuration Database Checker **********************************
// Extends config server class with command to scan through all 
// configs to check for errors
class ITUNECONFIGCHECK : public CONFIG {
private:
	static const CHAR* const aErrorString[];
protected:
	VOID	Error(CONFIG_ERROR eErrorType);
public:
	ITUNECONFIGCHECK() { }
	BOOL	ErrorScan();	// returns TRUE if any errors found
};

//***** Configuration Selector Class *************************************
// Modification of config server class to update config select file.
// This is used to control the currently selected satellite "mode"
// Note that private inheritance is used for code re-use.
const CHAR* const ITUNE_TEMPFILE = "itune.tmp";
class ITUNECONFIGSELECT : private CONFIG {
public:
	ITUNECONFIGSELECT() {}
	// SetMode returns TRUE if mode set
	BOOL SetMode(const CHAR* pszSatName, const CHAR* pszConfigID);
};
#endif // itune.hpp
