/****************************************************************************
Date: 12/27/97
File: mbradio.hpp
Description:
	Mic Button Radio Driver

	Note: Update() MUST be called once per DOS Timer tick

*****************************************************************************/
#ifndef MBRADIO_HPP
#define MBRADIO_HPP

#include "loctypes.h"

#include "ppdrv.hpp"		// Parallel port driver
#include "radio.hpp"		// RADIO base class
#include "kbdtune.hpp"		// keyboard tuner class

class MICBUTTONRADIO : public RADIO {
private:

	LONG	lVFOFreqSteps;
	LONG	lRITFreqSteps;
	LONG	lActualFreqSteps;
	LONG	lStepSize;
	enum	{ DEFAULTSTEP = 100 };	// Default step size = 100 Hz

	MODULATION	eModulation;

	enum	STATE { STATE_READY, STATE_BUSY };
	STATE	eState;

	// Data Output Bits
	enum	{ 
		UP	= 0x01 << 0,
		DOWN	= 0x01 << 1,
		LED = 0x01 << 2	// "Locked LED"
	};

	// Parallel Port Driver
	PPORTDRIVER	PortDriver;

	// Keyboard Tuner Driver
	KEYBOARDTUNER	KbdTuner;

	// Auxillary Functions
	LONG	FreqtoSteps(ULONG ulFrequency) {
		return (((LONG) ulFrequency) + (lStepSize/2) ) / lStepSize;
	}

	VOID PulseUp() {
		PortDriver.SetBits(UP);
		eState = STATE_BUSY;
	}

	VOID PulseDown() {
		PortDriver.SetBits(DOWN);
		eState = STATE_BUSY;
 	}

	VOID PulseEnd() {
		PortDriver.ClearBits(UP | DOWN);
		eState = STATE_READY;
	}

	VOID LEDOn() {
		PortDriver.SetBits(LED);
	}

	VOID LEDOff() {
		PortDriver.ClearBits(LED);
	}

	// Force compile error if attempted
	MICBUTTONRADIO(const MICBUTTONRADIO&);
	MICBUTTONRADIO& operator=(const MICBUTTONRADIO&);

public:
	MICBUTTONRADIO(const RADIOPARAMS& Params);
	~MICBUTTONRADIO();
	VOID	Update();

	// Tx Functions
	VOID	SetTxFreq(DOUBLE dFrequency);

	// Rx Functions
	BOOL	HasUserTunedRx();
	VOID	RefreshRxParams();
	DOUBLE	GetRxFreq();
	MODULATION GetRxMode();
	VOID	SetRxFreq(DOUBLE dFrequency);
	VOID	SetRxMode(MODULATION eMode);
};
#endif // mbradio.hpp
