/****************************************************************************
Date: 12/24/98
File: radio.cpp

Description:	RADIO and RADIOSYSTEM classes

	RADIO = base class for all radio drivers
	RADIOSYSTEM class has a RADIO driver plus frequency converters

History:
	11/25/97
	12/24/98 added FT-847
*****************************************************************************/

// Radio classes
#include "radio.hpp"
#include "kenwood.hpp"
#include "mbradio.hpp"
#include "ft736.hpp"
#include "ft847.hpp"

// Create a new radio driver
RADIO* RADIO::NewInstance(const RADIOPARAMS& Params) {

	RADIO* pRadio;
	switch(Params.eType) {
	case RADIOTYPE_NULL:
		pRadio = new RADIO();	// dummy driver
		break;

	case RADIOTYPE_KENWOOD:
		pRadio = new KENWOOD(Params);
		break;

	case RADIOTYPE_MICBUTTON:
		pRadio = new MICBUTTONRADIO(Params);
		break;

	case RADIOTYPE_FT736:
		pRadio = new FT736(Params);
		break;

	case RADIOTYPE_FT847:
		pRadio = new FT847(Params);
		break;

/**** ADD THESE LATER
	RADIOTYPE_TS790
	RADIOTYPE_ICOM
	RADIOTYPE_IC735
	RADIOTYPE_ICR7000
	RADIOTYPE_IC970
*****/
	default:
		// unknown type
		pRadio = NULL;
		break;

	} // end switch()

	// Check to make sure driver is OK
	// if not return NULL
	if (pRadio != NULL) {
		if (pRadio->IsOperational() == BOOL_FALSE) {
			delete pRadio;
			pRadio = NULL;
		}
	}
	return pRadio;
}

// Create a new RADIOSYSTEM
RADIOSYSTEM* RADIOSYSTEM::NewInstance(const RADIOPARAMS& Params) {
	RADIO* pRadio = RADIO::NewInstance(Params);
	if (pRadio == NULL) {
		return NULL;
	}
	return new RADIOSYSTEM(pRadio, Params);
}
