 /****************************************************************************
Date: 2/23/99
File: test1x.cpp
Description:	Radio Driver test program

History:
	Version 1.0 initial
	Version 1.1 - add timer interrupts
	Version 2.0 - test ft847 read VFO
	Version 2.1

*****************************************************************************/
#include <stdlib.h>
#include <string.h>
#include <dos.h>
#include <iostream.h>

#include "loctypes.h"
#include "dospc.h"
#include "inttimer.hpp"	// INTERVALTIMER class
#include "radio.hpp"


BOOL	eUpdate = BOOL_FALSE;
RADIOSYSTEM* pRadio = NULL;

//***** DOS Timer interrupt handler ***************************************
// Note: This routine gets called every ~55mSec. This routine runs
// with the interrupts OFF.
const INT CMD_INT_DOSTIMER   = 0x1C;	// DOS Timer interrupt
static INTHANDLER       pfnDosTimer;    // pointer to "real" DOS timer ISR
VOID INTERRUPT DOSTimerISR(VOID) {

	// Update Interval Timers
	INTERVALTIMER::Update();

	if (eUpdate) {
		pRadio->Update();
	}

        // let DOS timer handler run
        _chain_intr(pfnDosTimer);
}



static RADIOPARAMS Params = {

	RADIOTYPE_FT847, // Manufacturer/Model
	BOOL_TRUE,	// TRUE if using both TX and RX

	// I/O Params
	1, 		// COM or LPT Port number
	0, 		// IO port Base Address

	// Serial port Radios only
	0, 		// IRQ Number
	0, 		// Port bit Rate
	0,		// Radio Destination Address (ICOM)

	// Parallel port radios only
	0,		// initial frequency
	0,		// frequency step size

	// Frequency Converters
	0.0,		//dRxConverter;
	0.0		//dTxConverter;
};


main() {
	// Hook DOS Timer Interrupt
	disable();
        pfnDosTimer = getvect(CMD_INT_DOSTIMER);
	setvect(CMD_INT_DOSTIMER, DOSTimerISR);
	enable();

	cout << "FT-847 Test program 2-A" << endl;
	cout << "Runs at 4800 bps on COM 1" << endl;
	//cout << "TS-450 Test program 1" << endl;
	//cout << "This program test half-duplex mode" << endl;

	cout << endl << "Entering CAT mode" << endl;
	pRadio = RADIOSYSTEM::NewInstance(Params);
	if (!pRadio) {
		cout << "ERROR - Driver failed to initialize" << endl;
	}
	else {

		// Loop until user quits
		BOOL eLoop = BOOL_TRUE;
		DOUBLE dFrequency = 0.0;
		UINT unParam;
		eUpdate = BOOL_TRUE;
		while(1) {
			pRadio->RefreshRxParams();
			cout << "Polling radio..." << endl;
			sleep(2);
			if (pRadio->IsReady()) {
				if (pRadio->HasUserTunedRx()) {
					cout << "User has tuned";
				}
				else {
					cout << "User has not tuned";
				}
				cout << endl;

				cout << "Current Rx frequency=";
				cout << pRadio->GetRxFreq() << endl;
			}
			else {
				cout << "Error, Poll failed" << endl;
			}

/*****
			cout << "Please enter RX frequency in MHz: ";
			cin >> dFrequency;
			dFrequency *= 1.0e6;
			pRadio->SetRxFreq(dFrequency);

			cout << "Please enter TX frequency in MHz: ";
			cin >> dFrequency;
			dFrequency *= 1.0e6;
			pRadio->SetTxFreq(dFrequency);

			cout << "Please enter RX mode" << endl;
			cout << "(1=LSB, 2=USB, 3=CW, 4=FM): ";
			cin >> unParam;
			pRadio->SetRxMode((MODULATION) unParam);

			cout << "Please enter TX mode" << endl;
			cout << "(1=LSB, 2=USB, 3=CW, 4=FM): ";
			cin >> unParam;
			pRadio->SetTxMode((MODULATION) unParam);
*****/

			cout << "Do you want to run again?" << endl;
			cout << "Enter 1 to run again or 0 to quit: ";
			cin >> unParam;
			if (unParam == 0) {
				break;
			}
		}
		cout << "Thanks for running this test!" << endl;
		cout << "Turning off CAT mode" << endl;
		eUpdate = BOOL_FALSE;
		delete pRadio;
	}

	// un-hook DOS Timer Interrupt
	disable();
	setvect(CMD_INT_DOSTIMER, pfnDosTimer);
	enable();
	return 0;
}
